==> gitbook-nodejs-cli-1.1.0.tgz: package/lib/gitbook2_publisher.js <==
var _ = require("lodash");
var path = require("path");
var fs = require("fs");
var color = require('bash-color');

var Doc = require('./doc');
var upload = require('./upload');

var timeCount = new Date();
var countSuccess = 0;
function publish(dir){
    if(fs.existsSync(dir)){
        console.log("准备发布文档的项目文件夹：%s",dir);
        var doc = new Doc(dir);
        var config = doc.getConfig();
        if(!config){
            return;
        }
        if(!config.name){
            console.error(color.red("配置参数[name]不能为空：" + config.name));
            return;
        }
        if(!config.version){
            console.error(color.red("配置参数[version]不能为空：" + config.version));
            return;
        }
        if(!config.gitbookserver){
            console.error(color.red("配置参数[gitbookserver]不能为空：" + config.gitbookserver));
            return;
        }
        console.log(color.cyan("组件名：" + config.name));
        console.log(color.cyan("中文名：" + config.cnName));
        console.log(color.cyan("版本号：" + config.version));
        //去掉gitbookserver最后的/
        if(config.gitbookserver && _.endsWith(config.gitbookserver,"/"))
        {
            config.gitbookserver = config.gitbookserver.substring(0,config.gitbookserver.length - 1);
        }
        console.log(color.cyan("服务器：" + config.gitbookserver));
        console.log(color.cyan("描述：" + config.description));
        console.log(color.cyan("doc路径：" + doc.getDocDir()));

        var uploadUrl = config.gitbookserver + "/upload.do";
        doc.readAllSyn(function(result){
            console.log("待上传文件个数："+result.length);
            if(result.length > 0){
                timeCount = new Date();
                countSuccess = 0;
                uploadFiles(uploadUrl,doc.getDocDir(),config,result);
            }else{
                console.log(color.red("空文件夹[%s]，传什么传呢？"),doc.getDocDir());
            }
        });
    }else{
        console.log(color.red("文档文件夹的路径不存在[ %s ]"),dir);
    }
}
function uploadFiles(uploadUrl,docDir,config,files){
    if(!_.isEmpty(files)){
        var val = files.pop();
        val = val.replace(new RegExp(/\\/g),'/');
        var fullfileName = path.normalize(path.relative(docDir,val));
        fullfileName = fullfileName.replace(new RegExp(/\\/g),'/');
        var params = {
            'project': config.name,
            'version': config.version,
            'fullfileName':fullfileName
        }
        upload.uploadFile(uploadUrl,params,{ "file":val },function(res){
            console.log("准备上传文件:" + val);
            var result = JSON.parse(res);
            if(!result.status){
                console.log(color.red(JSON.stringify(params)));
                console.log(color.red("上传文件返回异常:" + res));
            }else{
                countSuccess++;
                uploadFiles(uploadUrl,docDir,config,files);
            }
        },function(type,err,response){
            console.log(color.red("上传异常",type,err,response.statusCode));
        });
    }else{
        //上传处理完成
        console.log(color.cyan("成功上传文件个数：%s 耗时：%s毫秒"),countSuccess,new Date().getTime() - timeCount.getTime());
        runCreateGitbook(config);
    }
}

function runCreateGitbook(config){
    console.log("\n开始生成gitbook...\n");
    var params = {
        "project":config.name,
        "version":config.version,
        "cnName":config.cnName,
        "desc":config.description
    }
    var uploadUrl = config.gitbookserver + "/rungitbook.do";
    upload.doPost(uploadUrl,params,function(result){
        var str = result;// result.replace(new RegExp(/\[0;36m/g),"\n");
//        str = str.replace(new RegExp(/\[0m/g),"");
//        str = str.replace(new RegExp(/\[0;32m/g),"");
//        var arr = str.split("\n");
//        _.forEach(arr,function(val){
//            console.log(val);
//        });
        console.log(str);
        if(result.indexOf("Done, without error")!=-1){
            console.log(color.green("\n恭喜，生成gitbook成功！(*^__^*) "));
            console.log(color.green("项目文档URL:%s/document/%s/%s/_book/index.html")
            ,config.gitbookserver,config.name,config.version);
        }else{
            console.log(color.red("生成gitbook失败"));
        }
    },function(type,err,response){
        console.log(color.red("http请求异常",type,err,response.statusCode ));
    });
}

module.exports = {
    publish:publish
};

==> gitbook-nodejs-cli-1.1.1.tgz: package/lib/gitbook2_publisher.js <==
var _ = require("lodash");
var path = require("path");
var fs = require("fs");
var color = require('bash-color');

var Doc = require('./doc');
var upload = require('./upload');

var timeCount = new Date();
var countSuccess = 0;
function publish(dir){
    if(fs.existsSync(dir)){
        console.log("准备发布文档的项目文件夹：%s",dir);
        var doc = new Doc(dir);
        var config = doc.getConfig();
        if(!config){
            return;
        }
        if(!config.name){
            console.error(color.red("配置参数[name]不能为空：" + config.name));
            return;
        }
        if(!config.version){
            console.error(color.red("配置参数[version]不能为空：" + config.version));
            return;
        }
        if(!config.gitbookserver){
            console.error(color.red("配置参数[gitbookserver]不能为空：" + config.gitbookserver));
            return;
        }
        console.log(color.cyan("组件名：" + config.name));
        console.log(color.cyan("中文名：" + config.cnName));
        console.log(color.cyan("版本号：" + config.version));
        //去掉gitbookserver最后的/
        if(config.gitbookserver && _.endsWith(config.gitbookserver,"/"))
        {
            config.gitbookserver = config.gitbookserver.substring(0,config.gitbookserver.length - 1);
        }
        console.log(color.cyan("服务器：" + config.gitbookserver));
        console.log(color.cyan("描述：" + config.description));
        console.log(color.cyan("doc路径：" + doc.getDocDir()));

        var uploadUrl = config.gitbookserver + "/upload.do";
        doc.readAllSyn(function(result){
            console.log("待上传文件个数："+result.length);
            if(result.length > 0){
                timeCount = new Date();
                countSuccess = 0;
                uploadFiles(uploadUrl,doc.getDocDir(),config,result);
            }else{
                console.log(color.red("空文件夹[%s]，传什么传呢？"),doc.getDocDir());
            }
        });
    }else{
        console.log(color.red("文档文件夹的路径不存在[ %s ]"),dir);
    }
}
function uploadFiles(uploadUrl,docDir,config,files){
    if(!_.isEmpty(files)){
        var val = files.pop();
        val = val.replace(new RegExp(/\\/g),'/');
        var fullfileName = path.normalize(path.relative(docDir,val));
        fullfileName = fullfileName.replace(new RegExp(/\\/g),'/');
        var params = {
            'project': config.name,
            'version': config.version,
            'fullfileName':fullfileName
        }
        upload.uploadFile(uploadUrl,params,{ "file":val },function(res){
            console.log("准备上传文件:" + val);
            var result = JSON.parse(res);
            if(!result.status){
                console.log(color.red(JSON.stringify(params)));
                console.log(color.red("上传文件返回异常:" + res));
            }else{
                countSuccess++;
                uploadFiles(uploadUrl,docDir,config,files);
            }
        },function(err,response){
            console.log(color.red("上传异常",err,response));
        });
    }else{
        //上传处理完成
        console.log(color.cyan("成功上传文件个数：%s 耗时：%s毫秒"),countSuccess,new Date().getTime() - timeCount.getTime());
        runCreateGitbook(config);
    }
}

function runCreateGitbook(config){
    console.log("\n开始生成gitbook...\n");
    var params = {
        "project":config.name,
        "version":config.version,
        "cnName":config.cnName,
        "desc":config.description
    }
    var uploadUrl = config.gitbookserver + "/rungitbook.do";
    upload.doPost(uploadUrl,params,function(result){
        var str = result;// result.replace(new RegExp(/\[0;36m/g),"\n");
//        str = str.replace(new RegExp(/\[0m/g),"");
//        str = str.replace(new RegExp(/\[0;32m/g),"");
//        var arr = str.split("\n");
//        _.forEach(arr,function(val){
//            console.log(val);
//        });
        console.log(str);
        if(result.indexOf("Done, without error")!=-1){
            console.log(color.green("\n恭喜，生成gitbook成功！(*^__^*) "));
            console.log(color.green("项目文档URL:%s/document/%s/%s/_book/index.html")
            ,config.gitbookserver,config.name,config.version);
        }else{
            console.log(color.red("生成gitbook失败"));
        }
    },function(type,err,response){
        console.log(color.red("http请求异常",err,response));
    });
}

module.exports = {
    publish:publish
};
